Welcome to CumulusCI's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   why_cumulusci
   demos
   install
   tutorial
   features
   robotframework
   robotframework-tutorial
   robotframework-debugger
   bulk_data
   metadata_etl
   cookbook
   cumulusci_flow
   usage

.. toctree::
   :maxdepth: 1

   tasks
   history
   authors
   contributing
   api_reference

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
